function PrintDescriptivesJCA(output,out_jca,detailed,ParallelAnalysis);
%prints the descriptives in the 'output' generated by CAnalysis.m
%
% INPUT
%       output      The 'output' structure generated by CAnalysis.m
%       detailed    1 -> Prints all the details
%                   0 -> Prints the basic information
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

if detailed == 1,

    disp(' ');
    me.str=sprintf('The %.0f x %.0f JCA modified Burt matrix',output.I,output.J);
    disp(me.str);
    disp(' ');
    CrossTabulateLabelsPrecision(out_jca.B, output.labels.r, output.labels.c);
    disp(' ');
    disp(' ');

    if isfield(output,'SupCol'),
        disp('Bust table related to supplementary variables');
        disp(' ');
        CrossTabulateLabels(output.SupCol, output.labels.r, output.labels.sc);
        disp(' ');
        disp(' ');       
    end;

   %Row and columns sums & masses
   disp('-------------------------------------------------------------------------');
   disp(' ');
   disp(' ');
   disp('Descriptives of variables');
   disp(' ');
   PrintMasses(output.N,output.labels.c);
   disp(' ');
   disp(' ');
   disp('Profiles of variables');
   disp(' ');
   CrossTabulateLabels(output.CP, output.labels.r, output.labels.c);
   disp(' ');
   disp(' ');
   %Matrix of standardized residuals
   disp('-------------------------------------------------------------------------');
   disp(' ');
   disp(' ');
   disp('Standardized residuals');
   disp(' ');
   CrossTabulateLabels(output.A, output.labels.r, output.labels.c);
   disp(' ');
   
end;

disp('-------------------------------------------------------------------------');
disp(' ');
disp(' ');
disp('Indices of association ');
disp(' ');
buff =sprintf('Dimensions    = %.0f',output.K);
disp(buff);
buff =sprintf('Chi-square    = %.5f',output.chis);
disp(buff);
buff =sprintf('Total inertia = %.5f',output.ti);
disp(buff);
buff =sprintf('Cramer`s V    = %.5f',output.CV);
disp(buff);
disp(' ');


disp('-------------------------------------------------------------------------');
disp(' ');
disp(' ');
disp('Principal inertias (eigenvalues)');
disp(' ');
PrintPrincipalInertias(output.eig); 
disp(' ');
disp(' ');
disp('Goodness-of-fit of Adjusted Correspondence Analysis');
disp(' ');
buff =sprintf('Total inertia in modified Burt matrix                         = %.4f',out_jca.i_total);
disp(buff);
buff =sprintf('Inertia due to diagonal tables                                = %.4f',out_jca.i_dia);
disp(buff);
buff =sprintf('Inertia due to off-diagonal tables                            = %.4f',out_jca.i_offdia);
disp(buff);
fit = (sum(output.eig(1:output.k,1)) - out_jca.i_dia)/(out_jca.i_total - out_jca.i_dia);
buff =sprintf('Goodness-of-fit for a model with %3.0f dimensions               = %.5f',output.k, fit);
disp(buff);
buff =sprintf('Percentatge of off-diagonal inertia explained by JCA solution = %.1f%%',fit*100);
disp(buff);
disp(' ');
disp(' ');


% if ParallelAnalysis == 1,
%     disp('-------------------------------------------------------------------------');
%     disp(' ');
%     disp('Parallel Analysis to determine the number of underlying dimensions (Lorenzo-Seva, 2011)');
%     disp(' ');
%     parallelCA(output.N,1,95);
%     disp(' ');
%     disp(' ');
% end;

return;