function PrintDescriptivesMCA(output,dataMCA,detailed,ParallelAnalysis);
%prints the descriptives in the 'output' generated by CAnalysis.m
%
% INPUT
%       output      The 'output' structure generated by CAnalysis.m
%       dataMCA     The structure of data related to MCA
%       detailed    1 -> Prints all the details
%                   0 -> Prints the basic information
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


if detailed == 1,

    %Crosstabulation matrix
    disp(' ');
    me.str=sprintf('Burt matrix table (%.0f x %.0f)',output.J,output.J);
%    me.str=sprintf('Burt matrix');
    disp(me.str);
    disp(' ');
    CrossTabulateLabels(dataMCA.B, output.labels.c, output.labels.c);
    disp(' ');
    disp(' ');

     if isfield(output,'SupCol'),
         disp('Burt matrix related to supplementary variables');
         disp(' ');
         CrossTabulateLabels(dataMCA.Bsup, output.labels.c, output.labels.sc);
         disp(' ');
         disp(' ');       
     end;

   %Row and columns sums & masses
   disp('-------------------------------------------------------------------------');
   disp(' ');
   disp(' ');
   disp('Descriptives of variables');
   disp(' ');
   PrintMasses(output.N,output.labels.c);
   disp(' ');
   disp(' ');
   disp('Profiles of variables');
   disp(' ');
   CrossTabulateLabels(output.CP, output.labels.r, output.labels.c);
   disp(' ');
   disp(' ');
   %Matrix of standardized residuals
   disp('-------------------------------------------------------------------------');
   disp(' ');
   disp(' ');
   disp('Standardized residuals');
   disp(' ');
   CrossTabulateLabels(output.A, output.labels.r, output.labels.c);
   disp(' ');
   
end;

disp('-------------------------------------------------------------------------');
disp(' ');
disp(' ');
disp('Indices of association ');
disp(' ');
buff =sprintf('Dimensions    = %.0f',output.K);
disp(buff);
buff =sprintf('Chi-square    = %.5f',output.chis);
disp(buff);
buff =sprintf('Total inertia = %.5f',output.ti);
disp(buff);
buff =sprintf('Cramer`s V    = %.5f',output.CV);
disp(buff);
disp(' ');

f=output.eig;
k=output.k;

disp('Dim   Intertia          %      Cum%');
disp(' ');
for i=1:k,
    buff1=sprintf('%3.0f     %6.4f     %6.1f    ',i,f(i,1),f(i,2)*100);   
    buff2=sprintf('%6.1f   ',f(i,3)*100);   
    buff4 = sprintf('%s%s',buff1,buff2);
    disp(buff4);    
end;
disp(' ');
disp(' ');

if ParallelAnalysis == 1,
    disp('-------------------------------------------------------------------------');
    disp(' ');
    disp('Parallel Analysis to determine the number of underlying dimensions (Lorenzo-Seva, 2011)');
    disp(' ');
    parallelCA(output.N,1,95);
    disp(' ');
    disp(' ');
end;

return;